

.. .. _dwl_api:

.. DimensionWithLabels
.. ^^^^^^^^^^^^^^^^^^^

.. .. currentmodule:: csdmpy._independent_variables
.. .. autoclass:: DimensionWithLabels
..     :show-inheritance:

..     .. rubric:: Attributes Summary

..     .. autosummary::

..         ~DimensionWithLabels.coordinates

..     .. rubric:: Attributes Documentation

..     .. autoattribute:: coordinates
